@@ -39,7 +39,7 @@ class ProducerQueue:
     def _publish_entity(self, exchange, routing_key, body,
                         type, priority=None, headers=None):
         properties = BasicProperties(
-            type=type, headers=headers) # priority=priority, 
+            type=type, headers=headers, priority=priority)
         self.channel.basic_publish(exchange=exchange,
                                    routing_key=routing_key,
                                    body=body,
